==> smartclientcore7.6.0-dev.zip: docs/constants/interfaces/interfaces/PublicAdAPI.md <==
[**smartclientcore**](README.md) • **Docs**

***

[smartclientcore](modules.md) / [constants/interfaces](constants/interfaces/README.md) / PublicAdAPI

# Interface: PublicAdAPI

## Properties

<a id="adid" name="adid"></a>

### adId

> `readonly` **adId**: `null` \| `string` \| `string`[]

***

<a id="adids" name="adids"></a>

### adIds

> `readonly` **adIds**: (`null` \| `string`)[]

***

<a id="adservingid" name="adservingid"></a>

### adServingId

> `readonly` **adServingId**: `null` \| `string`

***

<a id="closedcaptions" name="closedcaptions"></a>

### closedCaptions

> `readonly` **closedCaptions**: [`ClosedCaption`](constants/interfaces/interfaces/ClosedCaption.md)[]

***

<a id="companions" name="companions"></a>

### companions

> `readonly` **companions**: `any`[]

***

<a id="creativeids" name="creativeids"></a>

### creativeIds

> `readonly` **creativeIds**: [`CreativeIds`](constants/interfaces/interfaces/CreativeIds.md)

***

<a id="currenttime" name="currenttime"></a>

### currentTime

> `readonly` **currentTime**: `number`

***

<a id="duration" name="duration"></a>

### duration

> `readonly` **duration**: `number`

***

<a id="error" name="error"></a>

### error

> `readonly` **error**: [`ErrorStatus`](constants/interfaces/interfaces/ErrorStatus.md)

***

<a id="extensions" name="extensions"></a>

### extensions

> `readonly` **extensions**: [`Extension`](constants/interfaces/interfaces/Extension.md)[]

***

<a id="hasclickthrough" name="hasclickthrough"></a>

### hasClickThrough

> `readonly` **hasClickThrough**: `boolean`

***

<a id="height" name="height"></a>

### height

> `readonly` **height**: `number`

***

<a id="icons" name="icons"></a>

### icons

> `readonly` **icons**: `object` \| `object`

***

<a id="ids" name="ids"></a>

### ids

> `readonly` **ids**: (`null` \| `string`)[]

***

<a id="isexpanded" name="isexpanded"></a>

### isExpanded

> `readonly` **isExpanded**: `boolean`

***

<a id="isinteractive" name="isinteractive"></a>

### isInteractive

> `readonly` **isInteractive**: `boolean`

***

<a id="islinear" name="islinear"></a>

### isLinear

> `readonly` **isLinear**: `boolean`

***

<a id="isskippable" name="isskippable"></a>

### isSkippable

> `readonly` **isSkippable**: `boolean`

***

<a id="linear" name="linear"></a>

### linear

> `readonly` **linear**: [`AdCreative`](constants/interfaces/interfaces/AdCreative.md)

***

<a id="macrolist" name="macrolist"></a>

### macroList

> `readonly` **macroList**: `object`

***

<a id="nonlinear" name="nonlinear"></a>

### nonLinear

> `readonly` **nonLinear**: [] \| [`NonLinearVariation`](constants/interfaces/interfaces/NonLinearVariation.md)[]

***

<a id="remainingtime" name="remainingtime"></a>

### remainingTime

> `readonly` **remainingTime**: `number`

***

<a id="skipoffset" name="skipoffset"></a>

### skipOffset

> `readonly` **skipOffset**: `number`

***

<a id="title" name="title"></a>

### title

> `readonly` **title**: `string`

***

<a id="type" name="type"></a>

### type

> `readonly` **type**: `string`

***

<a id="universaladid" name="universaladid"></a>

### universalAdId

> `readonly` **universalAdId**: [`UniversalAdId`](constants/interfaces/interfaces/UniversalAdId.md)

***

<a id="universaladids" name="universaladids"></a>

### universalAdIds

> `readonly` **universalAdIds**: [`UniversalAdId`](constants/interfaces/interfaces/UniversalAdId.md)[]

***

<a id="variant" name="variant"></a>

### variant

> `readonly` **variant**: `string`

***

<a id="verifications" name="verifications"></a>

### verifications

> `readonly` **verifications**: [`AdVerification`](constants/interfaces/interfaces/AdVerification.md)[]

***

<a id="viewability" name="viewability"></a>

### viewability

> `readonly` **viewability**: [`Viewability`](constants/interfaces/interfaces/Viewability.md)

***

<a id="volume" name="volume"></a>

### volume

> **volume**: `number`

***

<a id="width" name="width"></a>

### width

> `readonly` **width**: `number`

***

<a id="wrappers" name="wrappers"></a>

### wrappers

> `readonly` **wrappers**: [`Wrapper`](constants/interfaces/interfaces/Wrapper.md)[]

==> smartclientcore7.6.1.zip: docs/constants/interfaces/interfaces/PublicAdAPI.md <==
[**smartclientcore**](README.md) • **Docs**

***

[smartclientcore](modules.md) / [constants/interfaces](constants/interfaces/README.md) / PublicAdAPI

# Interface: PublicAdAPI

## Properties

<a id="adid" name="adid"></a>

### adId

> `readonly` **adId**: `null` \| `string` \| `string`[]

***

<a id="adids" name="adids"></a>

### adIds

> `readonly` **adIds**: (`null` \| `string`)[]

***

<a id="adservingid" name="adservingid"></a>

### adServingId

> `readonly` **adServingId**: `null` \| `string`

***

<a id="closedcaptions" name="closedcaptions"></a>

### closedCaptions

> `readonly` **closedCaptions**: [`ClosedCaption`](constants/interfaces/interfaces/ClosedCaption.md)[]

***

<a id="companions" name="companions"></a>

### companions

> `readonly` **companions**: `any`[]

***

<a id="creativeids" name="creativeids"></a>

### creativeIds

> `readonly` **creativeIds**: [`CreativeIds`](constants/interfaces/interfaces/CreativeIds.md)

***

<a id="currenttime" name="currenttime"></a>

### currentTime

> `readonly` **currentTime**: `number`

***

<a id="duration" name="duration"></a>

### duration

> `readonly` **duration**: `null` \| `number`

***

<a id="error" name="error"></a>

### error

> `readonly` **error**: [`ErrorStatus`](constants/interfaces/interfaces/ErrorStatus.md)

***

<a id="extensions" name="extensions"></a>

### extensions

> `readonly` **extensions**: [`Extension`](constants/interfaces/interfaces/Extension.md)[]

***

<a id="hasclickthrough" name="hasclickthrough"></a>

### hasClickThrough

> `readonly` **hasClickThrough**: `boolean`

***

<a id="height" name="height"></a>

### height

> `readonly` **height**: `number`

***

<a id="icons" name="icons"></a>

### icons

> `readonly` **icons**: `object` \| `object`

***

<a id="ids" name="ids"></a>

### ids

> `readonly` **ids**: (`null` \| `string`)[]

***

<a id="isexpanded" name="isexpanded"></a>

### isExpanded

> `readonly` **isExpanded**: `boolean`

***

<a id="isinteractive" name="isinteractive"></a>

### isInteractive

> `readonly` **isInteractive**: `boolean`

***

<a id="islinear" name="islinear"></a>

### isLinear

> `readonly` **isLinear**: `boolean`

***

<a id="isskippable" name="isskippable"></a>

### isSkippable

> `readonly` **isSkippable**: `boolean`

***

<a id="linear" name="linear"></a>

### linear

> `readonly` **linear**: [`AdCreative`](constants/interfaces/interfaces/AdCreative.md)

***

<a id="macrolist" name="macrolist"></a>

### macroList

> `readonly` **macroList**: `object`

***

<a id="nonlinear" name="nonlinear"></a>

### nonLinear

> `readonly` **nonLinear**: [] \| [`NonLinearVariation`](constants/interfaces/interfaces/NonLinearVariation.md)[]

***

<a id="remainingtime" name="remainingtime"></a>

### remainingTime

> `readonly` **remainingTime**: `number`

***

<a id="skipoffset" name="skipoffset"></a>

### skipOffset

> `readonly` **skipOffset**: `number`

***

<a id="title" name="title"></a>

### title

> `readonly` **title**: `string`

***

<a id="type" name="type"></a>

### type

> `readonly` **type**: `string`

***

<a id="universaladid" name="universaladid"></a>

### universalAdId

> `readonly` **universalAdId**: [`UniversalAdId`](constants/interfaces/interfaces/UniversalAdId.md)

***

<a id="universaladids" name="universaladids"></a>

### universalAdIds

> `readonly` **universalAdIds**: [`UniversalAdId`](constants/interfaces/interfaces/UniversalAdId.md)[]

***

<a id="variant" name="variant"></a>

### variant

> `readonly` **variant**: `string`

***

<a id="verifications" name="verifications"></a>

### verifications

> `readonly` **verifications**: [`AdVerification`](constants/interfaces/interfaces/AdVerification.md)[]

***

<a id="viewability" name="viewability"></a>

### viewability

> `readonly` **viewability**: [`Viewability`](constants/interfaces/interfaces/Viewability.md)

***

<a id="volume" name="volume"></a>

### volume

> **volume**: `number`

***

<a id="width" name="width"></a>

### width

> `readonly` **width**: `number`

***

<a id="wrappers" name="wrappers"></a>

### wrappers

> `readonly` **wrappers**: [`Wrapper`](constants/interfaces/interfaces/Wrapper.md)[]
